summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorelie <elie>2012-08-12 07:16:14 +0000
committerelie <elie>2012-08-12 07:16:14 +0000
commit63be43104ae251af5d40d8d0b628768d07755690 (patch)
treee6ed3a7a9f07fca95942a249275227a4500d0042
parentba9eae4ff42297c6beeab8629914089a5012a9b0 (diff)
downloadpysnmp-63be43104ae251af5d40d8d0b628768d07755690.tar.gz
since MibVariable can handle incomplete MIB info, more rows is now
safe to request
-rw-r--r--examples/v3arch/oneliner/manager/nextgen.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/v3arch/oneliner/manager/nextgen.py b/examples/v3arch/oneliner/manager/nextgen.py
index 097b695..0f1a002 100644
--- a/examples/v3arch/oneliner/manager/nextgen.py
+++ b/examples/v3arch/oneliner/manager/nextgen.py
@@ -129,7 +129,7 @@ else:
# over Local Domain Sockets
# to an Agent at localhost:161
# for all OIDs past IF-MIB
# run till end-of-mib condition is reported by Agent OR maxRows == 20
# ignoring non-increasing OIDs whenever reported by Agent
# make sure IF-MIB.py is search path
@@ -139,7 +139,7 @@ errorIndication, errorStatus, errorIndex, varBindTable = cmdGen.nextCmd(
privProtocol=cmdgen.usmAesCfb128Protocol),
cmdgen.UdpTransportTarget(('localhost', 161)),
(('IF-MIB', ''),),
- lexicographicMode=True, #maxRows=20,
+ lexicographicMode=True, maxRows=100,
ignoreNonIncreasingOid=True
)
@@ -129,7 +129,7 @@ else:
# to an Agent at localhost:161
# for all OIDs past IF-MIB
-# run till end-of-mib condition is reported by Agent OR maxRows == 20
+# run till end-of-mib condition is reported by Agent OR maxRows == 100
# ignoring non-increasing OIDs whenever reported by Agent
# make sure IF-MIB.py is search path